@@ -4,7 +4,7 @@ use warnings;
 
 package Dancer2::Plugin::Auth::Tiny;
 # ABSTRACT: Require logged-in user for specified routes
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Carp qw/croak/;
 
@@ -47,7 +47,7 @@ sub _build_login {
         else {
             my $params = $request->params;
             my $data =
-              { $conf->{callback_key} => $request->uri_for( $request->path_info, $params->{query} ) };
+              { $conf->{callback_key} => $request->uri_for( $request->path, $params->{query} ) };
             for my $k ( @{ $conf->{passthrough} } ) {
                 $data->{$k} = $params->{$k} if $params->{$k};
             }
@@ -84,7 +84,7 @@ Dancer2::Plugin::Auth::Tiny - Require logged-in user for specified routes
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,7 @@ The code above is roughly equivalent to this:
     }
     else {
       return redirect uri_for( '/login',
-        { return_url => uri_for( request->path_info, request->params ) } );
+        { return_url => uri_for( request->path, request->params ) } );
     }
   };
 
